shortmag.net
-----------------------------

.. image:: https://travis-ci.org/xayon/shortmagnet.svg?branch=master
    :target: https://travis-ci.org/xayon/shortmagnet

.. image:: https://coveralls.io/repos/github/xayon/shortmagnet/badge.svg?branch=master
 :target: https://coveralls.io/github/xayon/shortmagnet?branch=master

.. image:: https://badge.fury.io/py/shortmagnet.svg
    :target: https://badge.fury.io/py/shortmagnet

Magnet-oriented URL Shortener.


Usage
-----

::

    Shortmag.net

    Magnet-oriented URL Shortener.

    Usage: shortmagnet [options]
